@@ -2,7 +2,12 @@
 # @author: leesoar
 
 """something."""
+import sys
 
 from crack.util import *
 
-__all__ = ["partition", "b64encode", "b64decode"]
+
+__version__ = "0.1.8"
+
+if sys.version_info >= (3, 6):
+    from secrets import *
